@@ -25,7 +25,6 @@
 
 #include "ephy-tree-model-node.h"
 #include "ephy-location-entry.h"
-#include "ephy-marshal.h"
 #include "ephy-signal-accumulator.h"
 #include "ephy-dnd.h"
 #include "egg-editable-toolbar.h"
@@ -212,7 +211,7 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (EphyLocationEntryClass, get_location),
 		ephy_signal_accumulator_string, NULL,
-		ephy_marshal_STRING__VOID,
+		g_cclosure_marshal_generic,
 		G_TYPE_STRING,
 		0,
 		G_TYPE_NONE);
@@ -232,7 +231,7 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (EphyLocationEntryClass, get_title),
 		ephy_signal_accumulator_string, NULL,
-		ephy_marshal_STRING__VOID,
+		g_cclosure_marshal_generic,
 		G_TYPE_STRING,
 		0,
 		G_TYPE_NONE);
@@ -1587,9 +1586,9 @@ ephy_location_entry_set_lock_stock (EphyLocationEntry *entry,
 	 * everything else, nothing is shown.
 	 */
 	if (!stock_id || g_str_equal (stock_id, STOCK_LOCK_BROKEN))
-		priv->lock_gicon = g_themed_icon_new_with_default_fallbacks ("changes-allow-symbolic");
+		priv->lock_gicon = g_themed_icon_new_with_default_fallbacks ("channel-insecure-symbolic");
 	else
-		priv->lock_gicon = g_themed_icon_new_with_default_fallbacks ("changes-prevent-symbolic");
+		priv->lock_gicon = g_themed_icon_new_with_default_fallbacks ("channel-secure-symbolic");
 
 	if (priv->show_lock)
 		gtk_entry_set_icon_from_gicon (GTK_ENTRY (priv->entry),
